﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Windows.Foundation;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Data;
using VSMWinRTDemo.RSS;
using Windows.Storage;
using Windows.ApplicationModel.DataTransfer;

namespace VSMWinRTDemo.UI
{
    partial class MainPage
    {
        private int _maxFeeds = 20;
        private RSSClient _client = new RSSClient();
        private DataTransferManager _dataTransferManager;

        public MainPage()
        {
            InitializeComponent();
            Loaded += new RoutedEventHandler(MainPage_Loaded);
            FeedListView.SelectionChanged += new SelectionChangedEventHandler(FeedListView_SelectionChanged);
            FetchButton.Click += new RoutedEventHandler(FetchButton_Click);
            _dataTransferManager = DataTransferManager.GetForCurrentView();
            _dataTransferManager.DataRequested += new TypedEventHandler<DataTransferManager, DataRequestedEventArgs>(MainPage_DataRequested);
        }

        void MainPage_DataRequested(DataTransferManager sender, DataRequestedEventArgs args)
        {
            // have a selected RSS feed item?
            if (FeedListView.SelectedItem != null)
            {
                RSSItem selectedItem = FeedListView.SelectedItem as RSSItem;
                args.Request.Data.Properties.Title = selectedItem.Title;
                args.Request.Data.Properties.Description = selectedItem.Description;
                args.Request.Data.SetText(selectedItem.Description);
                args.Request.Data.SetHtml(selectedItem.Description);

                if (selectedItem.Links.Count > 0)
                {
                    args.Request.Data.SetUri(selectedItem.Links[0].Link);
                }
            }
            else if(!String.IsNullOrWhiteSpace(FeedUrl.Text))
            {
                // share the loaded Feed URL
                args.Request.Data.Properties.Title = FeedTitle.Text;
                args.Request.Data.Properties.Description = "An RSS feed link from Daily Reader.";
                args.Request.Data.SetUri(new Uri(FeedUrl.Text));
            }
        }

        void FeedListView_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            ListView rssFeeds = (sender as ListView);
            RSSItem selectedItem = rssFeeds.SelectedItem as RSSItem;

            if (selectedItem != null && selectedItem.Links.Count > 0)
            {
                RSSItemWebView.Navigate(selectedItem.Links[0].Link);
            }
        }

        async void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            await GetFeeds("http://visualstudiomagazine.com/rss-feeds/columns.aspx"); 
        }

        private async void FetchButton_Click(object sender, RoutedEventArgs e)
        {
            if (!String.IsNullOrWhiteSpace(FeedUrl.Text))
            {
                await GetFeeds(FeedUrl.Text);
            }
        }

        private async Task GetFeeds(string url)
        {
            RSSFeed feeds = await _client.GetFeeds(url, _maxFeeds);
            this.DataContext = feeds;
        }
    }
}
